@@ -1,6 +1,6 @@
 use crate::api::Filter;
 
-impl_url_opts_builder!(PluginList);
+impl_opts_builder!(url => PluginList);
 
 pub enum PluginFilter {
     Capability(String),
@@ -19,5 +19,8 @@ impl Filter for PluginFilter {
 }
 
 impl PluginListOptsBuilder {
-    impl_filter_func!(PluginFilter);
+    impl_filter_func!(
+        /// Filter listed plugins by the variants of the enum.
+        PluginFilter
+    );
 }
